@@ -270,14 +270,17 @@ class BaseConfig(Configuration):
         'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
     }
     SIMPLE_JWT_SIGNING_KEY = values.Value()
+
     @property
     def SIMPLE_JWT(self):
         return {
             'ACCESS_TOKEN_LIFETIME': timedelta(hours=1),
             'REFRESH_TOKEN_LIFETIME': timedelta(hours=24),
             'SIGNING_KEY': self.SIMPLE_JWT_SIGNING_KEY or self.SECRET_KEY,
-            'ROTATE_REFRESH_TOKENS': True,
+            'ROTATE_REFRESH_TOKENS': False,
             'BLACKLIST_AFTER_ROTATION': True
         }
 
     CORS_ALLOWED_ORIGINS = values.ListValue()
+
+    SOCIALACCOUNT_STORE_TOKENS = True
